@@ -7,10 +7,20 @@ import attr
 
 from ._constants import DOCSTRING
 
-if sys.version_info[:2] >= (3,8):
-    _ast_str = ast.Constant
-else:
-    _ast_str = ast.Str
+
+def _get_str(node) -> Optional[str]:
+    # python <3.8
+    if sys.version_info[:2] < (3, 8):
+        if type(node) is ast.Str:
+            return node.s
+        return None
+
+    # python >=3.8
+    if type(node) is ast.Constant:
+        if type(node.value) is str:
+            return node.value
+    return None
+
 
 @attr.s(frozen=True)
 class Line:
@@ -55,26 +65,28 @@ class Line:
         if target.id not in cls._vars:
             return None
 
-        value = tree.body[0].value  # type: ignore
+        expr = tree.body[0].value  # type: ignore
 
         # get string
-        if type(value) is _ast_str:
+        value = _get_str(expr)
+        if value:
             return cls(
                 target=target.id,
-                value=value.s,
+                value=value,
                 content=content,
                 row=row,
                 path=path,
             )
 
         # get list
-        if type(value) is ast.List or type(value) is ast.Tuple:
-            for element in value.elts:
-                if type(element) is not _ast_str:
+        if type(expr) is ast.List or type(expr) is ast.Tuple:
+            elements = [_get_str(element) for element in expr.elts]
+            for element in elements:
+                if element is None:
                     return None
             return cls(
                 target=target.id,
-                value=[element.s for element in value.elts],
+                value=elements,
                 content=content,
                 row=row,
                 path=path,
